==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/SupportVectors.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}SupportVector" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfSupportVectors" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="numberOfAttributes" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "supportVectors"
})
@XmlRootElement(name = "SupportVectors")
public class SupportVectors
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "SupportVector", required = true)
    protected List<SupportVector> supportVectors;
    @XmlAttribute(name = "numberOfSupportVectors")
    protected BigInteger numberOfSupportVectors;
    @XmlAttribute(name = "numberOfAttributes")
    protected BigInteger numberOfAttributes;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the supportVectors property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the supportVectors property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getSupportVectors().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SupportVector }
     * 
     * 
     */
    public List<SupportVector> getSupportVectors() {
        if (supportVectors == null) {
            supportVectors = new ArrayList<SupportVector>();
        }
        return this.supportVectors;
    }

    /**
     * Gets the value of the numberOfSupportVectors property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfSupportVectors() {
        return numberOfSupportVectors;
    }

    /**
     * Sets the value of the numberOfSupportVectors property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfSupportVectors(BigInteger value) {
        this.numberOfSupportVectors = value;
    }

    /**
     * Gets the value of the numberOfAttributes property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfAttributes() {
        return numberOfAttributes;
    }

    /**
     * Sets the value of the numberOfAttributes property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfAttributes(BigInteger value) {
        this.numberOfAttributes = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof SupportVectors)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final SupportVectors that = ((SupportVectors) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<SupportVector> lhsSupportVectors;
            lhsSupportVectors = (((this.supportVectors!= null)&&(!this.supportVectors.isEmpty()))?this.getSupportVectors():null);
            List<SupportVector> rhsSupportVectors;
            rhsSupportVectors = (((that.supportVectors!= null)&&(!that.supportVectors.isEmpty()))?that.getSupportVectors():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "supportVectors", lhsSupportVectors), LocatorUtils.property(thatLocator, "supportVectors", rhsSupportVectors), lhsSupportVectors, rhsSupportVectors)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfSupportVectors;
            lhsNumberOfSupportVectors = this.getNumberOfSupportVectors();
            BigInteger rhsNumberOfSupportVectors;
            rhsNumberOfSupportVectors = that.getNumberOfSupportVectors();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfSupportVectors", lhsNumberOfSupportVectors), LocatorUtils.property(thatLocator, "numberOfSupportVectors", rhsNumberOfSupportVectors), lhsNumberOfSupportVectors, rhsNumberOfSupportVectors)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfAttributes;
            lhsNumberOfAttributes = this.getNumberOfAttributes();
            BigInteger rhsNumberOfAttributes;
            rhsNumberOfAttributes = that.getNumberOfAttributes();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfAttributes", lhsNumberOfAttributes), LocatorUtils.property(thatLocator, "numberOfAttributes", rhsNumberOfAttributes), lhsNumberOfAttributes, rhsNumberOfAttributes)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<SupportVector> theSupportVectors;
            theSupportVectors = (((this.supportVectors!= null)&&(!this.supportVectors.isEmpty()))?this.getSupportVectors():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "supportVectors", theSupportVectors), currentHashCode, theSupportVectors);
        }
        {
            BigInteger theNumberOfSupportVectors;
            theNumberOfSupportVectors = this.getNumberOfSupportVectors();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfSupportVectors", theNumberOfSupportVectors), currentHashCode, theNumberOfSupportVectors);
        }
        {
            BigInteger theNumberOfAttributes;
            theNumberOfAttributes = this.getNumberOfAttributes();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfAttributes", theNumberOfAttributes), currentHashCode, theNumberOfAttributes);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.3-sources.jar: org/dmg/pmml/SupportVectors.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}SupportVector" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfSupportVectors" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="numberOfAttributes" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "supportVectors"
})
@XmlRootElement(name = "SupportVectors")
public class SupportVectors
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "SupportVector", required = true)
    protected List<SupportVector> supportVectors;
    @XmlAttribute(name = "numberOfSupportVectors")
    protected BigInteger numberOfSupportVectors;
    @XmlAttribute(name = "numberOfAttributes")
    protected BigInteger numberOfAttributes;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the supportVectors property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the supportVectors property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getSupportVectors().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SupportVector }
     * 
     * 
     */
    public List<SupportVector> getSupportVectors() {
        if (supportVectors == null) {
            supportVectors = new ArrayList<SupportVector>();
        }
        return this.supportVectors;
    }

    /**
     * Gets the value of the numberOfSupportVectors property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfSupportVectors() {
        return numberOfSupportVectors;
    }

    /**
     * Sets the value of the numberOfSupportVectors property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfSupportVectors(BigInteger value) {
        this.numberOfSupportVectors = value;
    }

    /**
     * Gets the value of the numberOfAttributes property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNumberOfAttributes() {
        return numberOfAttributes;
    }

    /**
     * Sets the value of the numberOfAttributes property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNumberOfAttributes(BigInteger value) {
        this.numberOfAttributes = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof SupportVectors)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final SupportVectors that = ((SupportVectors) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<SupportVector> lhsSupportVectors;
            lhsSupportVectors = (((this.supportVectors!= null)&&(!this.supportVectors.isEmpty()))?this.getSupportVectors():null);
            List<SupportVector> rhsSupportVectors;
            rhsSupportVectors = (((that.supportVectors!= null)&&(!that.supportVectors.isEmpty()))?that.getSupportVectors():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "supportVectors", lhsSupportVectors), LocatorUtils.property(thatLocator, "supportVectors", rhsSupportVectors), lhsSupportVectors, rhsSupportVectors)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfSupportVectors;
            lhsNumberOfSupportVectors = this.getNumberOfSupportVectors();
            BigInteger rhsNumberOfSupportVectors;
            rhsNumberOfSupportVectors = that.getNumberOfSupportVectors();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfSupportVectors", lhsNumberOfSupportVectors), LocatorUtils.property(thatLocator, "numberOfSupportVectors", rhsNumberOfSupportVectors), lhsNumberOfSupportVectors, rhsNumberOfSupportVectors)) {
                return false;
            }
        }
        {
            BigInteger lhsNumberOfAttributes;
            lhsNumberOfAttributes = this.getNumberOfAttributes();
            BigInteger rhsNumberOfAttributes;
            rhsNumberOfAttributes = that.getNumberOfAttributes();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfAttributes", lhsNumberOfAttributes), LocatorUtils.property(thatLocator, "numberOfAttributes", rhsNumberOfAttributes), lhsNumberOfAttributes, rhsNumberOfAttributes)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<SupportVector> theSupportVectors;
            theSupportVectors = (((this.supportVectors!= null)&&(!this.supportVectors.isEmpty()))?this.getSupportVectors():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "supportVectors", theSupportVectors), currentHashCode, theSupportVectors);
        }
        {
            BigInteger theNumberOfSupportVectors;
            theNumberOfSupportVectors = this.getNumberOfSupportVectors();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfSupportVectors", theNumberOfSupportVectors), currentHashCode, theNumberOfSupportVectors);
        }
        {
            BigInteger theNumberOfAttributes;
            theNumberOfAttributes = this.getNumberOfAttributes();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfAttributes", theNumberOfAttributes), currentHashCode, theNumberOfAttributes);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<SupportVector> theSupportVectors;
            theSupportVectors = (((this.supportVectors!= null)&&(!this.supportVectors.isEmpty()))?this.getSupportVectors():null);
            strategy.appendField(locator, this, "supportVectors", buffer, theSupportVectors);
        }
        {
            BigInteger theNumberOfSupportVectors;
            theNumberOfSupportVectors = this.getNumberOfSupportVectors();
            strategy.appendField(locator, this, "numberOfSupportVectors", buffer, theNumberOfSupportVectors);
        }
        {
            BigInteger theNumberOfAttributes;
            theNumberOfAttributes = this.getNumberOfAttributes();
            strategy.appendField(locator, this, "numberOfAttributes", buffer, theNumberOfAttributes);
        }
        return buffer;
    }

}
